import { dataProperty, SwiftUICommon, BaseUIDataDriver } from './common';
import { Utils } from '@nativescript/core';
export * from './common';
const registry = new Map();
export function registerSwiftUI(id, callback) {
    registry.set(id, callback);
}
export class UIDataDriver extends BaseUIDataDriver {
    constructor(swiftUIProvider, owner) {
        super(owner);
        this.swiftUIProvider = swiftUIProvider;
    }
    createNativeView() {
        const vc = this.swiftUIProvider;
        return vc.view;
    }
    registerEvents(callback) {
        this.swiftUIProvider.onEvent = (data) => {
            callback(data);
        };
    }
    updateData(data) {
        this.swiftUIProvider.updateDataWithData(data);
    }
    onEvent(data) {
        const owner = this.owner.get();
        if (owner) {
            owner.notify({
                eventName: SwiftUICommon.swiftUIEventEvent,
                data: Utils.dataDeserialize(data),
            });
        }
    }
}
export class SwiftUI extends SwiftUICommon {
    createNativeView() {
        const generator = registry.get(this.swiftId);
        if (!generator) {
            console.warn('view not registered:', this.swiftId);
            return UIView.new();
        }
        this.driver = generator(this);
        return this.driver.createNativeView();
    }
    initNativeView() {
        if (!this.driver) {
            return;
        }
        this.driver.registerEvents((data) => {
            if (this.driver.onEvent) {
                this.driver.onEvent(data);
            }
            else {
                this.notify({
                    eventName: SwiftUI.swiftUIEventEvent,
                    data,
                });
            }
        });
    }
    disposeNativeView() {
        super.disposeNativeView();
        if (this.driver) {
            this.driver.destroyNativeView?.();
        }
    }
    [dataProperty.setNative](data) {
        this.updateData(data);
    }
    updateData(data) {
        this.driver?.updateData?.(data);
    }
}
export function openScene(options) {
    updateSceneData("NativeScriptOpenScene", options);
}
export function updateScene(options) {
    updateSceneData("NativeScriptUpdateScene", options);
}
function updateSceneData(eventName, options) {
    if (options.data) {
        NativeScriptSceneRegistry.shared.updateDataWithIdUpdates(options.id, options.data);
    }
    NSNotificationCenter.defaultCenter.postNotificationNameObjectUserInfo(eventName, null, Utils.dataSerialize({ type: options.id, isImmersive: options.isImmersive }));
}
//# sourceMappingURL=index.ios.js.map